GraviPy
=======

Tensor Calculus Package for General Relativity
based on SymPy (python library for symbolic mathematics).



Installation
------------

GraviPy depends on:

* Python (version >=2.6)
* SymPy (version >=7.3)
* IPython (version >=1.1.0)

IPython notebook isn't required but it makes it easier to work with complex 
mathematical formulas.

To install GraviPy, simply run

    $ python setup.py install

or

    $ pip install gravipy


Documentation and usage
-----------------------

docs/GraviPy-tutorial.ipynb

